| Title: | Estimator for Optimised Optional Randomised Response Technique |
|---|---|
| Description: | Provides functions for estimation under the Randomised Response Technique for sensitive survey data, including Warner's estimator, Optional Randomised Response Technique estimator proposed by Chaudhuri and Mukerjee,and the Optimized Optional Randomised Response Technique estimator proposed by Pushadapu et al. The package also includes Monte Carlo simulation tools for evaluating estimator performance. The implemented methods are based on Warner (1965) <doi:10.1080/01621459.1965.10480775>, Chaudhuri and Mukerjee (1985),and Pushadapu et al. (2025) <doi: 10.1111/insr.12581>. |
| Authors: | Safeela Nasrin [aut, cre], Kaustav Aditya [aut], Ritwika Das [aut] |
| Maintainer: | Safeela Nasrin <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-07-10 22:45:00 UTC |
| Source: | https://github.com/cran/OORRT |
Chaudhuri-Mukerjee Estimator
cm_estimator(PIAOM1H, p, X2, n, n1)cm_estimator(PIAOM1H, p, X2, n, n1)
PIAOM1H |
Observed proportion of "yes" responses among respondents who answered directly. |
p |
Warner probability |
X2 |
Number of "yes" responses from the Warner group (group sensitive to question) |
n |
Sample size |
n1 |
Number of respondents answering directly. |
CM estimator of PIA
## Example 5 from Pushadapu et al. (2025) ## COVID-19 prevalence survey among students n <- 145 n1 <- 101 x1 <- 42 x2 <- 18 p <- 0.3 PIAOM1H <- x1 / n1 ## Chaudhuri and Mukerjee estimator cm_estimator( PIAOM1H = PIAOM1H, p = p, X2 = x2, n = n, n1 = n1 )## Example 5 from Pushadapu et al. (2025) ## COVID-19 prevalence survey among students n <- 145 n1 <- 101 x1 <- 42 x2 <- 18 p <- 0.3 PIAOM1H <- x1 / n1 ## Chaudhuri and Mukerjee estimator cm_estimator( PIAOM1H = PIAOM1H, p = p, X2 = x2, n = n, n1 = n1 )
OORRT_Pushadapu Estimator
oorrt_pushadapu_estimator(PIAOM1H, X2, p, n, n1)oorrt_pushadapu_estimator(PIAOM1H, X2, p, n, n1)
PIAOM1H |
Observed proportion of "yes" responses among respondents who answered directly (group 1) |
X2 |
Number of "yes" responses from the Warner group (group sensitive to question= group 2) |
p |
Warner probability |
n |
Sample size |
n1 |
Number of respondents answering directly. |
A list with proposed estimator, ALPHA1H, ALPHA2H, MSE, CI bounds
## Example 5 from Pushadapu et al. (2025) ## COVID-19 prevalence survey among students n <- 145 n1 <- 101 x1 <- 42 x2 <- 18 p <- 0.3 PIAOM1H <- x1 / n1 oorrt_pushadapu_estimator( PIAOM1H = PIAOM1H, X2 = x2, p = p, n = n, n1 = n1 )## Example 5 from Pushadapu et al. (2025) ## COVID-19 prevalence survey among students n <- 145 n1 <- 101 x1 <- 42 x2 <- 18 p <- 0.3 PIAOM1H <- x1 / n1 oorrt_pushadapu_estimator( PIAOM1H = PIAOM1H, X2 = x2, p = p, n = n, n1 = n1 )
OORRT Simulation Study
orrt_simulation( nitr = 1000, p = 0.3, PIA_seq = seq(0.05, 0.45, 0.05), PIAOM1_seq = seq(0.2, 0.95, 0.05), n_seq = seq(150, 500, 50), W1_seq = seq(0.4, 0.7, 0.1) )orrt_simulation( nitr = 1000, p = 0.3, PIA_seq = seq(0.05, 0.45, 0.05), PIAOM1_seq = seq(0.2, 0.95, 0.05), n_seq = seq(150, 500, 50), W1_seq = seq(0.4, 0.7, 0.1) )
nitr |
Number of Monte Carlo iterations |
p |
Warner probability |
PIA_seq |
Sequence of true proportions to test |
PIAOM1_seq |
Sequence of group 1 proportions |
n_seq |
Sequence of sample sizes |
W1_seq |
Sequence of weights for group 1 |
Data frame with bias, MSE, RE, coverage, etc.
Warner Estimator
warner_estimator(n, p, X)warner_estimator(n, p, X)
n |
Sample size |
p |
Warner probability |
X |
no. of "yes" response |
Warner estimator of PIA